@@ -549,11 +549,12 @@ long DirList::onDNDMotion(FXObject* sender, FXSelector sel, void* ptr)
             getApp()->addTimeout(this, ID_EXPAND_TIMER, EXPAND_INTERVAL);
 
             // Set icon to open folder icon
-            setItemOpenIcon(item, minifolderopenicon);
+            setItemOpenIcon(item, minifolderopenicon);           
 
             // See if this is writable
             if (::isWritable(dropdirectory))
             {
+            	item->setSelected(TRUE);
                 acceptDrop(DRAG_ACCEPT);
                 int    x, y;
                 FXuint state;
@@ -565,6 +566,7 @@ long DirList::onDNDMotion(FXObject* sender, FXSelector sel, void* ptr)
                     if (!isItemCurrent(prevSelItem))
                     {
                         closeItem(prevSelItem);
+            			prevSelItem->setSelected(FALSE);
                     }
                     prevSelItem = NULL;
                 }
@@ -656,14 +658,21 @@ long DirList::onDNDDrop(FXObject* sender, FXSelector sel, void* ptr)
     // This is done before displaying the popup menu to fix a drag and drop problem with konqueror and dolphin file managers
     FXbool dnd = getDNDData(FROM_DRAGNDROP, urilistType, data, len);
 
+    int      xx, yy;
+    DirItem* item=NULL;
+
     // Display the dnd dialog if the control or shift key were not pressed
     if (confirm_dnd & !ctrlshiftkey)
     {
+		// Get item
+		FXuint state;
+		getCursorPosition(xx, yy, state);
+		item = (DirItem*)getItemAt(xx, yy);
+
         // Display a popup to select the drag type
         dropaction = DRAG_REJECT;
         FXMenuPane menu(this);
         int        x, y;
-        FXuint     state;
         getRoot()->getCursorPosition(x, y, state);
         new FXMenuCommand(&menu, _("Copy here"), copy_clpicon, this, DirList::ID_DRAG_COPY);
         new FXMenuCommand(&menu, _("Move here"), moveiticon, this, DirList::ID_DRAG_MOVE);
@@ -723,6 +732,11 @@ long DirList::onDNDDrop(FXObject* sender, FXSelector sel, void* ptr)
         }
         else
         {
+			// Deselect item
+			if (item)
+			{
+				item->setSelected(FALSE);
+			}
             FXFREE(&data);
             return(0);
         }
