@@ -407,6 +407,9 @@ FXuint File::getOverwriteAnswer(FXString srcpath, FXString tgtpath)
 
 
 // Copy ordinary file
+// Return  0 to allow displaying an error message in the calling function
+// Return -1 to prevent displaying an error message in the calling function
+// Return -2 when an error has occurred during the copy
 int File::copyfile(const FXString& source, const FXString& target, const FXbool preserve_date)
 {
     FXString       destfile;
@@ -438,6 +441,8 @@ int File::copyfile(const FXString& source, const FXString& target, const FXbool
             size = info.st_size;
             if ((dst = ::open(destfile.text(), O_WRONLY|O_CREAT|O_TRUNC, info.st_mode)) >= 0)
             {
+ 			   	int error = false;
+
                 while (1)
                 {
                     errno = 0;
@@ -467,6 +472,10 @@ int File::copyfile(const FXString& source, const FXString& target, const FXbool
                             cancelled = true;
                             return(false);
                         }
+                        else
+                        {
+							error = true; // An error has occurred
+						}
                     }
                     if (nread == 0)
                     {
@@ -558,9 +567,23 @@ int File::copyfile(const FXString& source, const FXString& target, const FXbool
                             cancelled = true;
                             return(false);
                         }
+                        else
+                        {
+							error = true; // An error has occurred
+						}
                     }
                 }
-                ok = true;
+
+				// An error has occurred during the copy 
+                if (error)
+                {
+                	ok = -2;
+				}
+                else
+                {
+                	ok = true;
+				}
+
                 ::close(dst);
 
                 // Keep original date if asked
@@ -639,7 +662,7 @@ int File::copyfile(const FXString& source, const FXString& target, const FXbool
             return(false);
         }
         ok = -1; // Prevent displaying an error message
-        // in the calling function
+                 // in the calling function
     }
     return(ok);
 }
@@ -1149,7 +1172,7 @@ int File::remove(const FXString& file)
                     return(false);
                 }
                 return(-1); // To prevent displaying an error message
-                // in the calling function
+                            // in the calling function
             }
             else
             {
@@ -1351,7 +1374,7 @@ int File::move(const FXString& source, const FXString& target, const FXbool rest
     }
 
     // Get the size of the source
-    FXulong     srcsize = 0;
+    FXulong srcsize = 0;
     struct stat linfo;
     if (lstatrep(source.text(), &linfo) == 0)
     {
@@ -1416,10 +1439,19 @@ int File::move(const FXString& source, const FXString& target, const FXbool rest
 
     int ret = this->copy(source, target, false, true);
 
+    // Success
     if (ret == true)
     {
         return(remove(source.text()) == true);
     }
+    
+    // Error during copy
+    else if (ret == -2)
+    {
+		return true;
+	}   
+    
+    // Operation cancelled
     else
     {
         return(false);
@@ -2043,6 +2075,8 @@ int File::mount(const FXString dir, const FXString msg, const FXString cmd, cons
         return(-1);
     }
 
+
+
     // Perform the mount/unmount command
     FILE* pcmd = popen(cmd.text(), "r");
     if (!pcmd)
@@ -2052,7 +2086,7 @@ int File::mount(const FXString dir, const FXString msg, const FXString cmd, cons
     }
 
     // Get error message if any
-    char     text[10000] = { 0 };
+    char text[10000] = { 0 };
     FXString buf;
     while (fgets(text, sizeof(text), pcmd))
     {
@@ -2066,6 +2100,39 @@ int File::mount(const FXString dir, const FXString msg, const FXString cmd, cons
         MessageBox::error(this, BOX_OK, _("Error"), "%s", text);
         return(-1);
     }
+
+
+
+#ifdef ZZZ
+
+FXString title = "titre";
+
+fprintf(stderr,"cmd = %s\n", cmd.text());
+
+
+FXString command;
+ 
+ // Semble marcher (il ne faut pas mettre le 2>&1 à la fin de la commande sinon ne marche pas !
+ // L'enlever de DirPanel.cpp et FilePanel.cpp si besoin !
+ command = "st -g 60x4 -t " + ::quote(title) + " " + cmd;
+
+ 
+fprintf(stderr,"command = %s\n",command.text());
+
+    // Execute su or sudo command in an internal st terminal
+    int status = runst(command);
+
+
+    if (status<0)
+    {
+        MessageBox::error(getApp(),BOX_OK,_("Error"),_("!!!!!An error has occurred!"));
+        //getApp()->endWaitCursor();
+        return (-1);
+    }
+
+#endif
+
+
     // Hide progress dialog
     hide();
 
